==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/nn_NO.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Ukjend feil",
    "Could not move %s - File with this name already exists" : "Klarte ikkje flytta %s – det finst allereie ei fil med dette namnet",
    "Could not move %s" : "Klarte ikkje flytta %s",
    "Unable to set upload directory." : "Klarte ikkje å endra opplastingsmappa.",
    "Invalid Token" : "Ugyldig token",
    "No file was uploaded. Unknown error" : "Ingen filer lasta opp. Ukjend feil",
    "There is no error, the file uploaded with success" : "Ingen feil, fila vart lasta opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Fila du lasta opp er større enn det «upload_max_filesize» i php.ini tillater: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den opplasta fila er større enn variabelen MAX_FILE_SIZE i HTML-skjemaet",
    "The uploaded file was only partially uploaded" : "Fila vart berre delvis lasta opp",
    "No file was uploaded" : "Ingen filer vart lasta opp",
    "Missing a temporary folder" : "Manglar ei mellombels mappe",
    "Failed to write to disk" : "Klarte ikkje skriva til disk",
    "Not enough storage available" : "Ikkje nok lagringsplass tilgjengeleg",
    "Upload failed. Could not find uploaded file" : "Feil ved opplasting. Klarte ikkje å finna opplasta fil.",
    "Upload failed. Could not get file info." : "Feil ved opplasting. Klarte ikkje å henta filinfo.",
    "Invalid directory." : "Ugyldig mappe.",
    "Files" : "Filer",
    "Favorites" : "Favorittar",
    "Home" : "Heime",
    "Close" : "Lukk",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Klarte ikkje å lasta opp {filename} sidan det er ei mappe eller er 0 byte.",
    "Upload cancelled." : "Opplasting avbroten.",
    "Could not get result from server." : "Klarte ikkje å henta resultat frå tenaren.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fila lastar no opp. Viss du forlèt sida no vil opplastinga verta avbroten.",
    "Actions" : "Handlingar",
    "Download" : "Last ned",
    "Rename" : "Endra namn",
    "Delete" : "Slett",
    "Details" : "Detaljar",
    "Pending" : "Under vegs",
    "Error moving file" : "Feil ved flytting av fil",
    "Error" : "Feil",
    "{new_name} already exists" : "{new_name} finst allereie",
    "Name" : "Namn",
    "Size" : "Storleik",
    "Modified" : "Endra",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_Uploading %n file_::_Uploading %n files_" : ["Lastar opp %n fil","Lastar opp %n filer"],
    "New" : "Ny",
    "File name cannot be empty." : "Filnamnet kan ikkje vera tomt.",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringa di er full, kan ikkje lenger oppdatera eller synkronisera!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringa di er nesten full ({usedSpacePercent} %)",
    "Favorite" : "Favoritt",
    "Upload" : "Last opp",
    "Text file" : "Tekst fil",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "A new file or folder has been <strong>created</strong>" : "Ei ny fil eller mappe er <strong>oppretta</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ei fil eller mappe er <strong>endra</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Ei fil eller mappe er <strong>sletta</strong>",
    "You created %1$s" : "Du oppretta %1$s",
    "%2$s created %1$s" : "%2$s oppretta %1$s",
    "%1$s was created in a public folder" : "%1$s oppretta i ei offentleg mappe",
    "You changed %1$s" : "Du endra %1$s",
    "%2$s changed %1$s" : "%2$s endra %1$s",
    "You deleted %1$s" : "Du sletta %1$s",
    "%2$s deleted %1$s" : "%2$s sletta %1$s",
    "%s could not be renamed" : "Klarte ikkje å omdøypa på %s",
    "File handling" : "Filhandtering",
    "Maximum upload size" : "Maksimal opplastingsstorleik",
    "max. possible: " : "maks. moglege:",
    "Save" : "Lagre",
    "Settings" : "Innstillingar",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Avbryt opplasting",
    "Upload too large" : "For stor opplasting",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å lasta opp er større enn maksgrensa til denne tenaren.",
    "Files are being scanned, please wait." : "Skannar filer, ver venleg og vent."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/nn_NO.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Ukjend feil",
    "Unable to set upload directory." : "Klarte ikkje å endra opplastingsmappa.",
    "Invalid Token" : "Ugyldig token",
    "No file was uploaded. Unknown error" : "Ingen filer lasta opp. Ukjend feil",
    "There is no error, the file uploaded with success" : "Ingen feil, fila vart lasta opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Fila du lasta opp er større enn det «upload_max_filesize» i php.ini tillater: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den opplasta fila er større enn variabelen MAX_FILE_SIZE i HTML-skjemaet",
    "The uploaded file was only partially uploaded" : "Fila vart berre delvis lasta opp",
    "No file was uploaded" : "Ingen filer vart lasta opp",
    "Missing a temporary folder" : "Manglar ei mellombels mappe",
    "Failed to write to disk" : "Klarte ikkje skriva til disk",
    "Not enough storage available" : "Ikkje nok lagringsplass tilgjengeleg",
    "Upload failed. Could not find uploaded file" : "Feil ved opplasting. Klarte ikkje å finna opplasta fil.",
    "Upload failed. Could not get file info." : "Feil ved opplasting. Klarte ikkje å henta filinfo.",
    "Invalid directory." : "Ugyldig mappe.",
    "Files" : "Filer",
    "Favorites" : "Favorittar",
    "Home" : "Heime",
    "Close" : "Lukk",
    "Upload cancelled." : "Opplasting avbroten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Klarte ikkje å lasta opp {filename} sidan det er ei mappe eller er 0 byte.",
    "Could not get result from server." : "Klarte ikkje å henta resultat frå tenaren.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fila lastar no opp. Viss du forlèt sida no vil opplastinga verta avbroten.",
    "Actions" : "Handlingar",
    "Download" : "Last ned",
    "Rename" : "Endra namn",
    "Delete" : "Slett",
    "Unshare" : "Udel",
    "Details" : "Detaljar",
    "Pending" : "Under vegs",
    "Name" : "Namn",
    "Size" : "Storleik",
    "Modified" : "Endra",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_Uploading %n file_::_Uploading %n files_" : ["Lastar opp %n fil","Lastar opp %n filer"],
    "New" : "Ny",
    "File name cannot be empty." : "Filnamnet kan ikkje vera tomt.",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringa di er full, kan ikkje lenger oppdatera eller synkronisera!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringa di er nesten full ({usedSpacePercent} %)",
    "Favorite" : "Favoritt",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "Upload" : "Last opp",
    "A new file or folder has been <strong>created</strong>" : "Ei ny fil eller mappe er <strong>oppretta</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ei fil eller mappe er <strong>endra</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Ei fil eller mappe er <strong>sletta</strong>",
    "You created %1$s" : "Du oppretta %1$s",
    "%2$s created %1$s" : "%2$s oppretta %1$s",
    "%1$s was created in a public folder" : "%1$s oppretta i ei offentleg mappe",
    "You changed %1$s" : "Du endra %1$s",
    "%2$s changed %1$s" : "%2$s endra %1$s",
    "You deleted %1$s" : "Du sletta %1$s",
    "%2$s deleted %1$s" : "%2$s sletta %1$s",
    "File handling" : "Filhandtering",
    "Maximum upload size" : "Maksimal opplastingsstorleik",
    "max. possible: " : "maks. moglege:",
    "Save" : "Lagre",
    "Settings" : "Innstillingar",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Avbryt opplasting",
    "Upload too large" : "For stor opplasting",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å lasta opp er større enn maksgrensa til denne tenaren.",
    "Text file" : "Tekst fil"
},
"nplurals=2; plural=(n != 1);");
